@@ -877,8 +877,9 @@ class Installer(object):
         newenv["MYSITEROOT"] = self._siteroot
         prefix = packageManager.getInstallPrefix()
         if prefix is not None:
-            self.log.warning("Setting RPM_INSTALL_PREFIX to %s" % prefix)
+            self.log.warning("Setting RPM_INSTALL_PREFIX and INSTALLDIR to %s" % prefix)
             newenv["RPM_INSTALL_PREFIX"] = prefix
+            newenv["INSTALLDIR"] = prefix
 
         import tempfile
         import subprocess
