@@ -15,8 +15,9 @@ and require attributes.
 
 :author: Ben Couturier
 '''
-
 import inspect
+from six.moves import urllib_parse
+
 
 # Deps added by RPM by default which we just ignore
 ##############################################################################
@@ -421,7 +422,7 @@ class Package(VersionedObject):  # IGNORE:R0902
         """ Returns the URL to download the file
 
         :returns: the full url of the remote rpm file"""
-        return self.repository.repourl + "/" + self.location
+        return urllib_parse.urljoin(self.repository.repourl, self.location)
 
     def fulfills(self, req):
         ''' Checks whether there is a provides for the package that
