@@ -73,7 +73,7 @@ class YumChecker(object):
         self._lcgDir = os.path.join(self._siteroot, "lcg")
         if config is None:
             from lbinstall.LHCbConfig import Config
-            config = Config()
+            config = Config(siteroot)
         self._config = config
         # Creating the install area and getting the relevant info
         self.__installArea = InstallArea(self._config, self._siteroot)
